You are viewing a plain text version of this content. The canonical link for it is here.
Posted to log4php-dev@logging.apache.org by ch...@apache.org on 2009/10/05 23:44:03 UTC

svn commit: r822035 - /incubator/log4php/branches/chammers/src/main/php/appenders/

Author: chammers
Date: Mon Oct  5 21:44:03 2009
New Revision: 822035

URL: http://svn.apache.org/viewvc?rev=822035&view=rev
Log:
* Added the previously committed examples to the phpdoc
* Added @package to the file level comment to make phpdoc happy
* Added some @var comments to aid IDE auto-completion
* No code change

Modified:
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderAdodb.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderConsole.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderDailyFile.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderEcho.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderFile.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderMail.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderMailEvent.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderNull.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderPDO.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderPhp.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderRollingFile.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderSocket.php
    incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderSyslog.php

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderAdodb.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderAdodb.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderAdodb.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderAdodb.php Mon Oct  5 21:44:03 2009
@@ -15,11 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- *
  * @package log4php
- * @subpackage appenders
  */
 
+/** A docblok to make phpdoc happy */
 require_once(ADODB_DIR . '/adodb.inc.php');
 
 /**

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderConsole.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderConsole.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderConsole.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderConsole.php Mon Oct  5 21:44:03 2009
@@ -15,16 +15,28 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
+ * @package log4php
  */
 
 /**
- * ConsoleAppender appends log events to STDOUT or STDERR using a layout specified by the user. 
+ * ConsoleAppender appends log events to STDOUT or STDERR. 
  * 
- * <p>Optional parameter is {@link $target}. The default target is Stdout.</p>
  * <p><b>Note</b>: Use this Appender with command-line php scripts. 
  * On web scripts this appender has no effects.</p>
- * <p>This appender requires a layout.</p>	
  *
+ * Configurable parameters of this appender are:
+ *
+ * - layout     - The layout (required)
+ * - target     - "stdout" or "stderr"
+ * 
+ * An example configuration file:
+ * 
+ * {@example ../../examples/resources/appender_console.properties}
+ * 
+ * An example php file:
+ * 
+ * {@example ../../examples/php/appender_console.php}
+ * 
  * @version $Revision$
  * @package log4php
  * @subpackage appenders

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderDailyFile.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderDailyFile.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderDailyFile.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderDailyFile.php Mon Oct  5 21:44:03 2009
@@ -15,16 +15,30 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
+ * @package log4php
  */
 
 /**
- * LoggerAppenderDailyFile appends log events to a file ne.
+ * An Appender that automatically creates a new logfile each day.
+ *
+ * The file is rolled over once a day. That means, for each day a new file 
+ * is created. A formatted version of the date pattern is used as to create 
+ * the file name using the {@link PHP_MANUAL#sprintf} function.
+ * 
+ * - layout             - Sets the layout class for this appender
+ * - datePattern        - Sets date format for the file name. Should be set before $file!
+ * - file               - The target file name. Should contain a '%s' which gets substituted by the date.
+ * - append             - Sets if the appender should append to the end of the file or overwrite content ("true" or "false")
+ * 
+ * An example configuration file:
+ * 
+ * {@example ../../examples/resources/appender_dailyfile.properties}
+ * 
+ * An example php file:
+ * 
+ * {@example ../../examples/php/appender_dailyfile.php}
  *
- * A formatted version of the date pattern is used as to create the file name
- * using the {@link PHP_MANUAL#sprintf} function.
- * <p>Parameters are {@link $datePattern}, {@link $file}. Note that file 
- * parameter should include a '%s' identifier and should always be set 
- * before {@link $file} param.</p>
+ * The above will create a file like: daily_20090908.log
  *
  * @version $Revision$
  * @package log4php

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderEcho.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderEcho.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderEcho.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderEcho.php Mon Oct  5 21:44:03 2009
@@ -15,9 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- *
  * @package log4php
- * @subpackage appenders
  */
 
 /**
@@ -25,6 +23,19 @@
  * 
  * <p>This appender requires a layout.</p>	
  *
+ * An example configuration file:
+ * 
+ * {@example ../../examples/resources/appender_echo.properties}
+ * 
+ * An example php file:
+ * 
+ * {@example ../../examples/php/appender_echo.php}
+ * 
+ * The above example would print the following:
+ * <pre>
+ *    Tue Sep  8 22:44:55 2009,812 [6783] DEBUG appender_echo - Hello World!
+ * </pre>
+ *
  * @version $Revision$
  * @package log4php
  * @subpackage appenders

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderFile.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderFile.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderFile.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderFile.php Mon Oct  5 21:44:03 2009
@@ -15,16 +15,26 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- *
  * @package log4php
- * @subpackage appenders
  */
 
 /**
  * FileAppender appends log events to a file.
  *
- * Parameters are ({@link $fileName} but option name is <b>file</b>), 
- * {@link $append}.
+ * Configurable parameters for this appender are:
+ * 
+ * - layout             - Sets the layout class for this appender
+ * - file               - The target file to write to
+ * - filename           - The target file to write to
+ * - append             - Sets if the appender should append to the end of the file or overwrite content ("true" or "false")
+ *
+ * An example configuration file:
+ * 
+ * {@example ../../examples/resources/appender_file.properties}
+ * 
+ * An example php file:
+ * 
+ * {@example ../../examples/php/appender_file.php}
  *
  * @version $Revision$
  * @package log4php

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderMail.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderMail.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderMail.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderMail.php Mon Oct  5 21:44:03 2009
@@ -15,17 +15,39 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- *
  * @package log4php
- * @subpackage appenders
  */
 
 /**
  * Appends log events to mail using php function {@link PHP_MANUAL#mail}.
  *
- * <p>Parameters are {@link $from}, {@link $to}, {@link $subject}.</p>
- * <p>This appender requires a layout.</p>
+ * The appender sends all log events at once after the request has been
+ * finsished and the appender is beeing closed.
  *
+ * Configurable parameters for this appender:
+ * 
+ * - layout             - Sets the layout class for this appender (required)
+ * - to                 - Sets the recipient of the mail (required)
+ * - from               - Sets the sender of the mail (optional)
+ * - subject            - Sets the subject of the mail (optional)
+ * 
+ * An example:
+ *
+ * {@example ../../examples/resources/appender_mail.properties}
+ * 
+ * {@example ../../examples/php/appender_mail.php}
+ * 
+ * The above will output something like:
+ * <pre>
+ *      Date: Tue,  8 Sep 2009 21:51:04 +0200 (CEST)
+ *      From: someone@example.com
+ *      To: root@localhost
+ *      Subject: Log4php test
+ *      
+ *      Tue Sep  8 21:51:04 2009,120 [5485] FATAL root - Some critical message!
+ *      Tue Sep  8 21:51:06 2009,120 [5485] FATAL root - Some more critical message!
+ * </pre>
+
  * @version $Revision$
  * @package log4php
  * @subpackage appenders

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderMailEvent.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderMailEvent.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderMailEvent.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderMailEvent.php Mon Oct  5 21:44:03 2009
@@ -15,21 +15,36 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- *
  * @package log4php
- * @subpackage appenders
  */
 
 /**
- * Log events to an email address. It will be created an email for each event. 
+ * Log every events as a separate email.
+ * 
+ * Configurable parameters for this appender are:
+ * 
+ * - layout             - Sets the layout class for this appender (required)
+ * - to                 - Sets the recipient of the mail (required)
+ * - from               - Sets the sender of the mail (optional)
+ * - subject            - Sets the subject of the mail (optional)
+ * - smtpHost           - Sets the mail server (optional, default is ini_get('SMTP'))
+ * - port               - Sets the port of the mail server (optional, default is 25)
+ *
+ * An example:
+ * 
+ * {@example ../../examples/resources/appender_mailevent.properties}
+ *
+ * {@example ../../examples/php/appender_mailevent.php}
+ * 
+ * The above will output something like:
+ * <pre>
+ *      Date: Tue,  8 Sep 2009 21:51:04 +0200 (CEST)
+ *      From: someone@example.com
+ *      To: root@localhost
+ *      Subject: Log4php test
  *
- * <p>Parameters are 
- * {@link $smtpHost} (optional), 
- * {@link $port} (optional), 
- * {@link $from} (optional), 
- * {@link $to}, 
- * {@link $subject} (optional).</p>
- * <p>A layout is required.</p>
+ *      Tue Sep  8 21:51:04 2009,120 [5485] FATAL root - Some critical message!
+ * </pre>
  *
  * @version $Revision$
  * @package log4php

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderNull.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderNull.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderNull.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderNull.php Mon Oct  5 21:44:03 2009
@@ -15,14 +15,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- *
  * @package log4php
- * @subpackage appenders
  */
 
 /**
  * A NullAppender merely exists, it never outputs a message to any device.	
  *
+ * This appender has no configurable parameters.
+ * 
+ * An example:
+ * 
+ * {@example ../../examples/php/appender_null.php}
+ * 
+ * {@example ../../examples/resources/appender_null.properties}
+ * 
  * @version $Revision$
  * @package log4php
  * @subpackage appenders

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderPDO.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderPDO.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderPhp.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderPhp.php Mon Oct  5 21:44:03 2009
@@ -15,16 +15,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
+ * @package log4php
  */
 
 /**
  * Log events using php {@link PHP_MANUAL#trigger_error} function and a {@link LoggerLayoutTTCC} default layout.
  *
+ * This appender has no configurable parameters.
+ *
  * <p>Levels are mapped as follows:</p>
  * - <b>level &lt; WARN</b> mapped to E_USER_NOTICE
  * - <b>WARN &lt;= level &lt; ERROR</b> mapped to E_USER_WARNING
  * - <b>level &gt;= ERROR</b> mapped to E_USER_ERROR  
  *
+ * An example:
+ * 
+ * {@example ../../examples/php/appender_php.php}
+ * 
+ * {@example ../../examples/resources/appender_php.properties}
+ *
  * @version $Revision$
  * @package log4php
  * @subpackage appenders

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderRollingFile.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderRollingFile.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderRollingFile.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderRollingFile.php Mon Oct  5 21:44:03 2009
@@ -15,17 +15,36 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
+ * @package log4php
  */
 
 /**
  * LoggerAppenderRollingFile extends LoggerAppenderFile to backup the log files 
  * when they reach a certain size.
  *
- * <p>Parameters are {@link $maxFileSize}, {@link $maxBackupIndex}.</p> 
+ * Parameters are:
+ * 
+ * - layout            - Sets the layout class for this appender
+ * - file              - The target file to write to
+ * - filename          - The target file to write to
+ * - append            - Sets if the appender should append to the end of the file or overwrite content ("true" or "false")
+ * - maxBackupIndex    - Set the maximum number of backup files to keep around (int)
+ * - maxFileSize       - Set the maximum size that the output file is allowed to 
+ *                       reach before being rolled over to backup files.
+ *                       Suffixes like "KB", "MB" or "GB" are allowed, f. e. "10KB" is interpreted as 10240
+ * - maximumFileSize   - Alias to MaxFileSize
  *
  * <p>Contributors: Sergio Strampelli.</p>
  *
+ * An example:
+ * 
+ * {@example ../../examples/php/appender_socket.php}
+ * 
+ * {@example ../../examples/resources/appender_socket.properties}
+ * 
  * @version $Revision$
+ * @example ../../examples/php/appender_rollingfile.php   An example how to use this class
+ * @example ../../examples/resources/appender_rollingfile.properties   Configuration example
  * @package log4php
  * @subpackage appenders
  */

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderSocket.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderSocket.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderSocket.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderSocket.php Mon Oct  5 21:44:03 2009
@@ -15,14 +15,31 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
+ * @package log4php
  */
 
 /**
  * Serialize events and send them to a network socket.
  *
+ * This appender can be configured by changing the following attributes:
+ * 
+ * - locationInfo       - Sets the location info for the xml layout (true or false)
+ * - log4jNamespace     - Sets the namespace for log4j (true or false)
+ * - port               - Sets the port of the socket.
+ * - remoteHost         - Sets the remote host
+ * - timeout            - Sets the timeout in ms
+ * - useXml             - true, if xml should be transmitted.
+ *                        false, if a serialized php object should be transmitted
+ *
  * Parameters are {@link $remoteHost}, {@link $port}, {@link $timeout}, 
  * {@link $locationInfo}, {@link $useXml} and {@link $log4jNamespace}.
  *
+ * An example:
+ * 
+ * {@example ../../examples/php/appender_socket.php}
+ * 
+ * {@example ../../examples/resources/appender_socket.properties}
+ * 
  * @version $Revision$
  * @package log4php
  * @subpackage appenders
@@ -216,9 +233,6 @@
 		$this->useXml = LoggerOptionConverter::toBoolean($flag, $this->getUseXml());
 	} 
  
-	/**
-	 * @param LoggerLoggingEvent
-	 */
 	public function append(LoggerLoggingEvent $event) {
 		if($this->sp || $this->dry) {
 			if($this->getLocationInfo()) {

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderSyslog.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderSyslog.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderSyslog.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderSyslog.php Mon Oct  5 21:44:03 2009
@@ -15,11 +15,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
+ * @package log4php
  */
 
 /**
  * Log events using php {@link PHP_MANUAL#syslog} function.
  *
+ * This appender can be configured by changing the following attributes:
+ * 
+ * - layout           - Sets the layout class for this appender
+ * - ident            - Set the ident of the syslog message.
+ * - priority         - Set the priority value for the syslog message.
+ * - facility         - Set the facility value for the syslog message
+ * - overridePriority - If the priority of the message to be sent can be 
+ *                      defined by a value in the properties-file, set 
+ *                      parameter value to "true"
+ * - option           - Set the option value for the syslog message. 
+ *                      This value is used as a parameter for php openlog()
+ *                      and passed on to the syslog daemon.
+ *
  * Levels are mapped as follows:
  * - <b>level >= FATAL</b> to LOG_ALERT
  * - <b>FATAL > level >= ERROR</b> to LOG_ERR 
@@ -27,9 +41,13 @@
  * - <b>WARN  > level >= INFO</b> to LOG_INFO
  * - <b>INFO  > level >= DEBUG</b> to LOG_DEBUG
  *
+ * An example:
+ * 
+ * {@example ../../examples/php/appender_syslog.php}
+ * 
+ * {@example ../../examples/resources/appender_syslog.properties}
+ * 
  * @version $Revision$
- * @example ../../examples/php/syslog.php   An example how to use the LoggerAppenderSyslog class
- * @example ../../examples/resources/syslog.properties   Configuration example
  * @package log4php
  * @subpackage appenders
  */
--- incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderPDO.php (original)
+++ incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderPDO.php Mon Oct  5 21:44:03 2009
@@ -14,42 +14,81 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
+ *
+ * @package log4php
  */
 
 /**
- * Appends log events to a db table using PDO
+ * Appends log events to a db table using PDO.
+ *
+ * Configurable parameters of this appender are:
+ *
+ * - user            - Sets the user of this database connection
+ * - password        - Sets the password of this database connection
+ * - createTable     - true, if the table should be created if necessary. false otherwise
+ * - table           - Sets the table name (default: log4php_log)
+ * - sql             - Sets the insert statement for a logging event. Defaults
+ *                     to the correct one - change only if you are sure what you are doing.
+ * - dsn             - Sets the DSN string for this connection
+ *
+ * If $sql is set then $table and $sql are used, else $table, $insertSql and $insertPattern.
  *
- * <p>This appender uses a table in a database to log events.</p>
- * <p>Parameters are {@link $host}, {@link $user}, {@link $password},
- * {@link $database}, {@link $createTable}, {@link $table} and {@link $sql}.</p>
+ * An example:
  *
+ * {@example ../../examples/php/appender_pdo.php}
+ * 
+ * {@example ../../examples/resources/appender_pdo.properties}
+ * 
+ * @version $Revision: 806678 $
  * @package log4php
  * @subpackage appenders
  * @since 2.0
  */
 class LoggerAppenderPDO extends LoggerAppender {
-    /** Create the log table if it does not exists (optional). */
+
+    /** Create the log table if it does not exists (optional).
+     * @var string */
 	private $createTable = true;
     
-    /** Database user name */
+    /** Database user name.
+     * @var string */
     private $user = '';
     
-    /** Database password */
+    /** Database password
+     * @var string */
     private $password = '';
     
-	/** DSN string for enabling a connection */    
+    /** DSN string for enabling a connection.
+     * @var string */
     private $dsn;
     
     /** A {@link LoggerPatternLayout} string used to format a valid insert query (mandatory) */
     private $sql;
     
-    /** Table name to write events. Used only if {@link $createTable} is true. */    
+    /** Can be set to a complete insert statement with ? that are replaced using {@link insertPattern}.
+     * @var string */
+    private $insertSql = "INSERT INTO __TABLE__ (timestamp, logger, level, message, thread, file, line) VALUES (?,?,?,?,?,?,?)";
+
+    /** A comma separated list of {@link LoggerPatternLayout} format strings that replace the "?" in {@link $sql}.
+     * @var string */
+    private $insertPattern = "%d,%c,%p,%m,%t,%F,%L";
+
+    /** Table name to write events. Used only for CREATE TABLE if {@link $createTable} is true.
+     * @var string */
     private $table = 'log4php_log';
     
-    /** The instance */
+    /** The PDO instance.
+     * @var PDO */
     private $db = null;
     
-    /** boolean used to check if all conditions to append are true */
+    /** Prepared statement for the INSERT INTO query.
+     * @var PDOStatement */
+    private $preparedInsert;
+
+    /** Set in activateOptions() and later used in append() to check if all conditions to append are true.
+     * @var boolean */
     private $canAppend = true;
     
     /**
@@ -211,7 +250,9 @@
     /**
      * Sometimes databases allow only one connection to themselves in one thread.
      * SQLite has this behaviour. In that case this handle is needed if the database
-     * must be checked for events
+     * must be checked for events.
+     *
+     * @return PDO
      */
     public function getDatabaseHandle() {
         return $this->db;
@@ -14,42 +14,81 @@
     private $dsn;
     
-    /** A {@link LoggerPatternLayout} string used to format a valid insert query (mandatory) */
+    /** A {@link LoggerPatternLayout} string used to format a valid insert query.
+     * @deprecated Use {@link $insertSql} and {@link $insertPattern} which properly handle quotes in the messages!
+     * @var string */
     private $sql;
     

Modified: incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderPhp.php
URL: http://svn.apache.org/viewvc/incubator/log4php/branches/chammers/src/main/php/appenders/LoggerAppenderPhp.php?rev=822035&r1=822034&r2=822035&view=diff
==============================================================================